@@ -13,7 +13,7 @@ package Printer::ESCPOS::Manual;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 1;
 
@@ -27,7 +27,7 @@ Printer::ESCPOS::Manual - Manual for Printing POS Receipts using Printer::ESCPOS
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS 
 
@@ -259,7 +259,7 @@ Sets Upside Down Printing onE<sol>off (pass B<0> or B<1>)
 
 =head3 fontHeight 
 
-Set font height. Only supports B<0> or B<1> for printmode set to 1, supports values B<0>,*1*,*2*,*3*,*4*,*5*,*6* and B<7> for non-printmode state (default) 
+Set font height. Only supports B<0> or B<1> for printmode set to 1, supports values B<0>, B<1>, B<2>, B<3>, B<4>, B<5>, B<6> and B<7> for non-printmode state (default) 
 
      $device->printer->fontHeight(1);
      $device->printer->write("double height\n");
@@ -271,7 +271,7 @@ Set font height. Only supports B<0> or B<1> for printmode set to 1, supports val
 
 =head3 fontWidth 
 
-Set font width. Only supports B<0> or B<1> for printmode set to 1, supports values B<0>,*1*,*2*,*3*,*4*,*5*,*6* and B<7> for non-printmode state (default) 
+Set font width. Only supports B<0> or B<1> for printmode set to 1, supports values B<0>, B<1>, B<2>, B<3>, B<4>, B<5>, B<6> and B<7> for non-printmode state (default) 
 
      $device->printer->fontWidth(1);
      $device->printer->write("double width\n");
@@ -283,7 +283,7 @@ Set font width. Only supports B<0> or B<1> for printmode set to 1, supports valu
 
 =head3 charSpacing
 
-Sets character spacing takes a value between 0 and 255
+Sets character spacing. Takes a value between 0 and 255
 
      $device->printer->charSpacing(5);
      $device->printer->write("Blah Blah Blah\n");
@@ -291,7 +291,7 @@ Sets character spacing takes a value between 0 and 255
 
 =head3 lineSpacing 
 
-Sets the spacing between each line of printout.
+Sets the line spacing i.e the spacing between each line of printout.
 
      $device->printer->lineSpacing($spacing);
 
@@ -299,13 +299,13 @@ Sets the spacing between each line of printout.
 
 =item *
 
-0 E<lt>= spacing E<lt>= 255
+0 E<lt>= $spacing E<lt>= 255
 
 =back
 
 =head3 selectDefaultLineSpacing 
 
-Revert to default Line spacing for the printer
+Reverts to default line spacing for the printer
 
      $device->printer->selectDefaultLineSpacing();
 
@@ -329,9 +329,10 @@ Sets the distance from the beginning of the line to the position at which charac
 
 =head3 leftMargin
 
-Sets the left margin code to the printer. takes two single byte parameters, I<nL> and I<nH>.
-To determine the value of these two bytes, use the INT and MOD conventions. INT indicates the integer (or whole number) part of a number, while MOD indicates the
-remainder of a division operation. Must be sent before a new line begins to be effective.
+Sets the left margin. Takes two single byte parameters, I<nL> and I<nH>.
+
+To determine the value of these two bytes, use the INT and MOD conventions. INT indicates the integer (or whole number) part of a number, while MOD indicates the remainder of a division operation. Must be sent before a new line begins to be effective.
+
 For example, to break the value 520 into two bytes, use the following two equations:
 I<nH> = INT 520E<sol>256
 I<nL> = MOD 520E<sol>256
@@ -362,7 +363,8 @@ However there are several customizations available including barcode I<system>,
          height      => $height,        # no of dots in vertical direction
          system      => $system,        # Barcode system
          width       => 2               # 2:0.25mm, 3:0.375mm, 4:0.5mm, 5:0.625mm, 6:0.75mm
-         barcode     => '123456789012', # Check barcode systems for allowed value
+         barcode     => '123456789012', # Check barcode system you are using for allowed 
+                                        # characters in barcode
      );
      $device->printer->barcode(
          system      => 'CODE39',
@@ -375,7 +377,7 @@ However there are several customizations available including barcode I<system>,
          barcode     => 'Shan',
      );
 
-Available systems:
+Available barcode I<systems>:
 
 =over
 
@@ -446,7 +448,6 @@ $flag = 3 # Double width and Double Height
 =head3 printImage
 
 Prints bit image stored in Volatile memory of the printer. This image gets erased when printer is reset. 
-This function also writes the buffer data to the printer before printing the bit image. 
 
      $device->printer->printImage($flag);
 
