@@ -13,7 +13,7 @@ package Printer::ESCPOS::Profiles::Generic;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -480,7 +480,7 @@ Printer::ESCPOS::Profiles::Generic - Generic Profile for Printers for Printer::E
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 METHODS
 
@@ -630,7 +630,7 @@ Sets Upside Down Printing on/off (pass *0* or *1*)
 
 =head2 fontHeight 
 
-Set font height. Only supports *0* or *1* for printmode set to 1, supports values *0*,*1*,*2*,*3*,*4*,*5*,*6* and *7* for non-printmode state (default) 
+Set font height. Only supports *0* or *1* for printmode set to 1, supports values *0*, *1*, *2*, *3*, *4*, *5*, *6* and *7* for non-printmode state (default) 
 
     $device->printer->fontHeight(1);
     $device->printer->write("double height\n");
@@ -642,7 +642,7 @@ Set font height. Only supports *0* or *1* for printmode set to 1, supports value
 
 =head2 fontWidth 
 
-Set font width. Only supports *0* or *1* for printmode set to 1, supports values *0*,*1*,*2*,*3*,*4*,*5*,*6* and *7* for non-printmode state (default) 
+Set font width. Only supports *0* or *1* for printmode set to 1, supports values *0*, *1*, *2*, *3*, *4*, *5*, *6* and *7* for non-printmode state (default) 
 
     $device->printer->fontWidth(1);
     $device->printer->write("double width\n");
@@ -662,15 +662,15 @@ Sets character spacing takes a value between 0 and 255
 
 =head2 lineSpacing 
 
-Sets the spacing between each line of printout.
+Sets the line spacing i.e the spacing between each line of printout.
 
     $device->printer->lineSpacing($spacing);
 
-* 0 <= spacing <= 255
+* 0 <= $spacing <= 255
 
 =head2 selectDefaultLineSpacing 
 
-Revert to default Line spacing for the printer
+Reverts to default line spacing for the printer
 
     $device->printer->selectDefaultLineSpacing();
 
@@ -685,9 +685,10 @@ Sets the distance from the beginning of the line to the position at which charac
 
 =head2 leftMargin
 
-Sets the left margin code to the printer. takes two single byte parameters, ~nL~ and ~nH~.
-To determine the value of these two bytes, use the INT and MOD conventions. INT indicates the integer (or whole number) part of a number, while MOD indicates the
-remainder of a division operation. Must be sent before a new line begins to be effective.
+Sets the left margin. Takes two single byte parameters, ~nL~ and ~nH~.
+
+To determine the value of these two bytes, use the INT and MOD conventions. INT indicates the integer (or whole number) part of a number, while MOD indicates the remainder of a division operation. Must be sent before a new line begins to be effective.
+
 For example, to break the value 520 into two bytes, use the following two equations:
 ~nH~ = INT 520/256
 ~nL~ = MOD 520/256
@@ -718,7 +719,8 @@ However there are several customizations available including barcode ~system~, ~
         height      => $height,        # no of dots in vertical direction
         system      => $system,        # Barcode system
         width       => 2               # 2:0.25mm, 3:0.375mm, 4:0.5mm, 5:0.625mm, 6:0.75mm
-        barcode     => '123456789012', # Check barcode systems for allowed value
+        barcode     => '123456789012', # Check barcode system you are using for allowed 
+                                       # characters in barcode
     );
     $device->printer->barcode(
         system      => 'CODE39',
@@ -731,7 +733,7 @@ However there are several customizations available including barcode ~system~, ~
         barcode     => 'Shan',
     );
 
-Available systems:
+Available barcode ~systems~:
 
 * UPC-A
 * UPC-C
@@ -757,7 +759,6 @@ Prints bit image stored in Non-Volatile (NV) memory of the printer.
 =head2 printImage
 
 Prints bit image stored in Volatile memory of the printer. This image gets erased when printer is reset. 
-This function also writes the buffer data to the printer before printing the bit image. 
 
     $device->printer->printImage($flag);
 
